# hipopayflake

>
> version: 1.1.2
>
> author: [KuangQingxu](mailto:asahikuang@gmail?subject=[hipopayflake])
>
> date: 2020-12-11
>
> update: 2020-12-11

### Usage:

    - To be continue

### Packaging And Uploading:

- Packing:

    ```
    python setup.py sdist bdist_wheel
    ```

- Uploading:

    ```
    twine upload --repository-url https://upload.pypi.org/legacy/ dist/*
    ```
